SessionRuntimeConfig

Struct SessionRuntimeConfig 

pub struct SessionRuntimeConfig {
    pub pyspark_compat: PysparkCompat,
    pub ansi_enabled: bool,
    pub disable_map_key_normalization: bool,
    pub infer_map_type_from_first_pair: bool,
    pub infer_array_type_from_first_element: bool,
    pub legacy_postgres_datetime_mapping: bool,
    pub legacy_mysql_datetime_mapping: bool,
    pub legacy_oracle_timestamp_mapping: bool,
    pub legacy_mssqlserver_datetime_mapping: bool,
    pub legacy_db2_datetime_mapping: bool,
}
Execution semantics derived from spark.conf and compat profile.

Fields

pyspark_compat: PysparkCompatansi_enabled: booldisable_map_key_normalization: boolinfer_map_type_from_first_pair: boolinfer_array_type_from_first_element: boollegacy_postgres_datetime_mapping: bool

PySpark 3.5 JDBC datetime mapping for PostgreSQL (legacy restore).

legacy_mysql_datetime_mapping: bool

PySpark 3.5 JDBC type mapping for MySQL/MariaDB (legacy restore).

legacy_oracle_timestamp_mapping: bool

PySpark 3.5 JDBC timestamp write mapping for Oracle (legacy restore).

legacy_mssqlserver_datetime_mapping: bool

PySpark 3.5 JDBC type mapping for SQL Server (legacy restore).

legacy_db2_datetime_mapping: bool

PySpark 3.5 JDBC type mapping for DB2 (legacy restore).

Implementations

Source

impl SessionRuntimeConfig

pub fn for_compat(compat: PysparkCompat) -> Self

Bundle defaults for a compatibility profile.

pub fn from_session_map(map: &HashMap<String, String>) -> Self

Parse from session config map (and optional env compat before session is built).

pub fn apply_profile_to_map(&self, map: &mut HashMap<String, String>)

Apply profile bundle keys into a session config map (used when setting compat).

pub fn set_compat_profile( map: &mut HashMap<String, String>, compat: PysparkCompat, )

Apply compat profile and write bundled keys into the map.

pub fn compat_from_env() -> Option<PysparkCompat>

Read compat from environment (SPARKLESS_PYSPARK_COMPAT).